==> ember-cli-page-object-1.8.0.tgz: package/addon/-private/properties/triggerable.js <==
import { assign, buildSelector, findClosestValue } from '../helpers';
import { getExecutionContext } from '../execution_context';

/**
 *
 * Triggers event on element matched by selector.
 *
 * @example
 *
 * // <input class="name">
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   focus: triggerable('focus', '.name')
 * });
 *
 * // focuses on element with selector '.name'
 * page.focus();
 *
 * @example
 *
 * // <input class="name">
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   enter: triggerable('keypress', '.name', { eventProperties: { keyCode: 13 } })
 * });
 *
 * // triggers keypress using enter key on element with selector '.name'
 * page.enter();
 *
 * @example
 *
 * // <div class="scope">
 * //   <input class="name">
 * // </div>
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   focus: triggerable('focus', '.name', { scope: '.scope' })
 * });
 *
 * // focuses on element with selector '.scope .name'
 * page.focus();
 *
 * @example
 *
 * // <div class="scope">
 * //   <input class="name">
 * // </div>
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   scope: '.scope',
 *   focus: triggerable('focus', '.name')
 * });
 *
 * // clicks on element with selector '.scope button.continue'
 * page.focus();
 *
 * @public
 *
 * @param {string} event - Event to be triggered
 * @param {string} selector - CSS selector of the element on which the event will be triggered
 * @param {Object} options - Additional options
 * @param {string} options.scope - Nests provided scope within parent's scope
 * @param {number} options.at - Reduce the set of matched elements to the one at the specified index
 * @param {boolean} options.resetScope - Ignore parent scope
 * @param {String} options.testContainer - Context where to search elements in the DOM
 * @param {String} options.eventProperties - Event properties that will be passed to trigger function
 * @return {Descriptor}
*/
export function triggerable(event, selector, userOptions = {}) {
  return {
    isDescriptor: true,

    get(key) {
      return function() {
        let executionContext = getExecutionContext(this);
        let options = assign({ pageObjectKey: `${key}()` }, userOptions);

        return executionContext.runAsync((context) => {
          let fullSelector = buildSelector(this, selector, options);
          let container =  options.testContainer || findClosestValue(this, 'testContainer');

          context.assertElementExists(fullSelector, options);

          context.triggerEvent(fullSelector, container, event, options.eventProperties);
        });
      };
    }
  };
}

==> ember-cli-page-object-1.10.0.tgz: package/addon/-private/properties/triggerable.js <==
import { assign, buildSelector, findClosestValue } from '../helpers';
import { getExecutionContext } from '../execution_context';

/**
 *
 * Triggers event on element matched by selector.
 *
 * @example
 *
 * // <input class="name">
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   focus: triggerable('focus', '.name')
 * });
 *
 * // focuses on element with selector '.name'
 * page.focus();
 *
 * @example
 *
 * // <input class="name">
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   enter: triggerable('keypress', '.name', { eventProperties: { keyCode: 13 } })
 * });
 *
 * // triggers keypress using enter key on element with selector '.name'
 * page.enter();
 *
 * @example
 *
 * // <div class="scope">
 * //   <input class="name">
 * // </div>
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   focus: triggerable('focus', '.name', { scope: '.scope' })
 * });
 *
 * // focuses on element with selector '.scope .name'
 * page.focus();
 *
 * @example
 *
 * // <div class="scope">
 * //   <input class="name">
 * // </div>
 * // <input class="email">
 *
 * const page = PageObject.create({
 *   scope: '.scope',
 *   focus: triggerable('focus', '.name')
 * });
 *
 * // clicks on element with selector '.scope button.continue'
 * page.focus();
 *
 * @public
 *
 * @param {string} event - Event to be triggered
 * @param {string} selector - CSS selector of the element on which the event will be triggered
 * @param {Object} options - Additional options
 * @param {string} options.scope - Nests provided scope within parent's scope
 * @param {number} options.at - Reduce the set of matched elements to the one at the specified index
 * @param {boolean} options.resetScope - Ignore parent scope
 * @param {string} options.testContainer - Context where to search elements in the DOM
 * @param {string} options.eventProperties - Event properties that will be passed to trigger function
 * @return {Descriptor}
*/
export function triggerable(event, selector, userOptions = {}) {
  return {
    isDescriptor: true,

    get(key) {
      return function() {
        let executionContext = getExecutionContext(this);
        let options = assign({ pageObjectKey: `${key}()` }, userOptions);

        return executionContext.runAsync((context) => {
          let fullSelector = buildSelector(this, selector, options);
          let container =  options.testContainer || findClosestValue(this, 'testContainer');

          context.assertElementExists(fullSelector, options);

          context.triggerEvent(fullSelector, container, event, options.eventProperties);
        });
      };
    }
  };
}
